==> seedsui-react-5.7.84.tgz: package/lib/Tabs/Tabs.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["className", "average", "contentProps", "captionProps", "sndcaptionProps", "value", "list", "disabled", "onChange"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Tabs = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$className = _ref.className,
    className = _ref$className === void 0 ? 'tabs-line tabs-line-width-percent70 border-b' : _ref$className,
    _ref$average = _ref.average,
    average = _ref$average === void 0 ? false : _ref$average,
    _ref$contentProps = _ref.contentProps,
    contentProps = _ref$contentProps === void 0 ? {} : _ref$contentProps,
    _ref$captionProps = _ref.captionProps,
    captionProps = _ref$captionProps === void 0 ? {} : _ref$captionProps,
    _ref$sndcaptionProps = _ref.sndcaptionProps,
    sndcaptionProps = _ref$sndcaptionProps === void 0 ? {} : _ref$sndcaptionProps,
    value = _ref.value,
    _ref$list = _ref.list,
    list = _ref$list === void 0 ? [] : _ref$list,
    disabled = _ref.disabled,
    onChange = _ref.onChange,
    others = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  function handleClick(e) {
    var target = e.target;
    var index = target.getAttribute('data-index');
    if (!index) return;
    if (onChange) {
      onChange(list[index], {
        event: e
      });
      e.stopPropagation();
    }
  }

  // 根据value判断此项是否为选中状态
  function getIsActive(item) {
    if (Object.prototype.toString.call(value) === '[object Object]') {
      if (item.id && value.id) {
        return item.id === value.id;
      } else if (item.name && value.name) {
        return item.name === value.name;
      } else if (item.caption && value.caption) {
        return item.caption === value.caption;
      } else {
        return false;
      }
    }
    return false;
  }

  // 图标DOM
  function getIcon(icon, iconActive, isActive) {
    if (isActive) {
      return iconActive ? iconActive : icon;
    }
    return icon;
  }

  // 内容DOM
  function getTabsContent() {
    var _others$style;
    if (!Array.isArray(list)) {
      console.log('SeedsUI: Tabs的传入参数list类型不正确');
      return null;
    }
    // tabStyle高度
    var tabStyle = {};
    if (others !== null && others !== void 0 && others.style && others !== null && others !== void 0 && (_others$style = others.style) !== null && _others$style !== void 0 && _others$style.height) {
      tabStyle = {
        height: others.style.height
      };
    }
    // 遍历
    return list.map(function (item, index) {
      var icon = item.icon,
        iconActive = item.iconActive,
        ricon = item.ricon,
        riconActive = item.riconActive,
        name = item.name,
        caption = item.caption,
        sndcaption = item.sndcaption,
        _item$attribute = item.attribute,
        attribute = _item$attribute === void 0 ? {} : _item$attribute;
      var isActive = getIsActive(item);
      var liconDOM = null;
      if (icon) {
        liconDOM = getIcon(icon, iconActive, isActive);
      }
      var riconDOM = null;
      if (ricon) {
        riconDOM = getIcon(ricon, riconActive, isActive);
      }
      return /*#__PURE__*/_jsxs("li", _objectSpread(_objectSpread({
        className: "tab".concat(isActive ? ' active' : ''),
        "data-index": index
      }, attribute), {}, {
        style: Object.assign(tabStyle, (attribute === null || attribute === void 0 ? void 0 : attribute.style) || {}),
        children: [liconDOM && liconDOM, /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({
          className: "tab-content"
        }, contentProps), {}, {
          children: [/*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, captionProps), {}, {
            className: "tab-caption".concat(captionProps.className ? ' ' + captionProps.className : ''),
            children: caption || name
          })), sndcaption && /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, sndcaptionProps), {}, {
            className: "tab-sndcaption".concat(sndcaptionProps.className ? ' ' + sndcaptionProps.className : ''),
            children: sndcaption
          }))]
        })), riconDOM && riconDOM]
      }), index);
    });
  }

  // 获取tabs的DOM
  var tabsContent = getTabsContent();
  return /*#__PURE__*/_jsx("ul", _objectSpread(_objectSpread({}, others), {}, {
    className: "tabs animated".concat(average ? ' tabs-tab-average' : '').concat(className ? ' ' + className : ''),
    disabled: disabled,
    onClick: handleClick,
    ref: rootRef,
    children: tabsContent
  }));
});
export default Tabs;

==> seedsui-react-5.8.10.tgz: package/lib/Tabs/Tabs.js <==
var _excluded = ["className", "average", "contentProps", "captionProps", "sndcaptionProps", "value", "list", "disabled", "onChange"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
var Tabs = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$className = _ref.className,
    className = _ref$className === void 0 ? 'tabs-line tabs-line-width-percent70 border-b' : _ref$className,
    _ref$average = _ref.average,
    average = _ref$average === void 0 ? false : _ref$average,
    _ref$contentProps = _ref.contentProps,
    contentProps = _ref$contentProps === void 0 ? {} : _ref$contentProps,
    _ref$captionProps = _ref.captionProps,
    captionProps = _ref$captionProps === void 0 ? {} : _ref$captionProps,
    _ref$sndcaptionProps = _ref.sndcaptionProps,
    sndcaptionProps = _ref$sndcaptionProps === void 0 ? {} : _ref$sndcaptionProps,
    value = _ref.value,
    _ref$list = _ref.list,
    list = _ref$list === void 0 ? [] : _ref$list,
    disabled = _ref.disabled,
    onChange = _ref.onChange,
    others = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  function handleClick(e) {
    var target = e.target;
    var index = target.getAttribute('data-index');
    if (!index) return;
    if (onChange) {
      onChange(list[index], {
        event: e
      });
      e.stopPropagation();
    }
  }

  // 根据value判断此项是否为选中状态
  function getIsActive(item) {
    if (Object.prototype.toString.call(value) === '[object Object]') {
      if (item.id && value.id) {
        return item.id === value.id;
      } else if (item.name && value.name) {
        return item.name === value.name;
      } else if (item.caption && value.caption) {
        return item.caption === value.caption;
      } else {
        return false;
      }
    }
    return false;
  }

  // 图标DOM
  function getIcon(icon, iconActive, isActive) {
    if (isActive) {
      return iconActive ? iconActive : icon;
    }
    return icon;
  }

  // 内容DOM
  function getTabsContent() {
    var _others$style;
    if (!Array.isArray(list)) {
      console.log('SeedsUI: Tabs的传入参数list类型不正确');
      return null;
    }
    // tabStyle高度
    var tabStyle = {};
    if (others !== null && others !== void 0 && others.style && others !== null && others !== void 0 && (_others$style = others.style) !== null && _others$style !== void 0 && _others$style.height) {
      tabStyle = {
        height: others.style.height
      };
    }
    // 遍历
    return list.map(function (item, index) {
      var icon = item.icon,
        iconActive = item.iconActive,
        ricon = item.ricon,
        riconActive = item.riconActive,
        name = item.name,
        caption = item.caption,
        sndcaption = item.sndcaption,
        _item$attribute = item.attribute,
        attribute = _item$attribute === void 0 ? {} : _item$attribute;
      var isActive = getIsActive(item);
      var liconDOM = null;
      if (icon) {
        liconDOM = getIcon(icon, iconActive, isActive);
      }
      var riconDOM = null;
      if (ricon) {
        riconDOM = getIcon(ricon, riconActive, isActive);
      }
      return /*#__PURE__*/React.createElement("li", _extends({
        className: "tab".concat(isActive ? ' active' : ''),
        "data-index": index,
        key: index
      }, attribute, {
        style: Object.assign(tabStyle, (attribute === null || attribute === void 0 ? void 0 : attribute.style) || {})
      }), liconDOM && liconDOM, /*#__PURE__*/React.createElement("div", _extends({
        className: "tab-content"
      }, contentProps), /*#__PURE__*/React.createElement("div", _extends({}, captionProps, {
        className: "tab-caption".concat(captionProps.className ? ' ' + captionProps.className : '')
      }), caption || name), sndcaption && /*#__PURE__*/React.createElement("div", _extends({}, sndcaptionProps, {
        className: "tab-sndcaption".concat(sndcaptionProps.className ? ' ' + sndcaptionProps.className : '')
      }), sndcaption)), riconDOM && riconDOM);
    });
  }

  // 获取tabs的DOM
  var tabsContent = getTabsContent();
  return /*#__PURE__*/React.createElement("ul", _extends({}, others, {
    className: "tabs animated".concat(average ? ' tabs-tab-average' : '').concat(className ? ' ' + className : ''),
    disabled: disabled,
    onClick: handleClick,
    ref: rootRef
  }), tabsContent);
});
export default Tabs;
